==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/tt.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'tt', {
	button: {
		title: 'Төймә үзлекләре',
		text: 'Text (Value)', // MISSING
		type: 'Төр',
		typeBtn: 'Төймә',
		typeSbm: 'Submit', // MISSING
		typeRst: 'Reset' // MISSING
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox Properties', // MISSING
		radioTitle: 'Radio Button Properties', // MISSING
		value: 'Value', // MISSING
		selected: 'Сайланган'
	},
	form: {
		title: 'Форма үзлекләре',
		menu: 'Форма үзлекләре',
		action: 'Гамәл',
		method: 'Ысул',
		encoding: 'Кодировка'
	},
	hidden: {
		title: 'Яшерен кыр үзлекләре',
		name: 'Исем',
		value: 'Күләм'
	},
	select: {
		title: 'Selection Field Properties', // MISSING
		selectInfo: 'Select Info', // MISSING
		opAvail: 'Available Options', // MISSING
		value: 'Күләм',
		size: 'Зурлык',
		lines: 'юллар',
		chkMulti: 'Allow multiple selections', // MISSING
		opText: 'Текст',
		opValue: 'Күләм',
		btnAdd: 'Кушу',
		btnModify: 'Үзгәртү',
		btnUp: 'Өскә',
		btnDown: 'Аска',
		btnSetValue: 'Set as selected value', // MISSING
		btnDelete: 'Бетерү'
	},
	textarea: {
		title: 'Текст мәйданы үзлекләре',
		cols: 'Баганалар',
		rows: 'Юллар'
	},
	textfield: {
		title: 'Текст кыры үзлекләре',
		name: 'Исем',
		value: 'Күләм',
		charWidth: 'Символлар киңлеге',
		maxChars: 'Maximum Characters', // MISSING
		type: 'Төр',
		typeText: 'Текст',
		typePass: 'Сер сүз',
		typeEmail: 'Эл. почта',
		typeSearch: 'Эзләү',
		typeTel: 'Телефон номеры',
		typeUrl: 'Сылталама'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/tt.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'tt', {
	button: {
		title: 'Төймә үзлекләре',
		text: 'Текст (күләм)',
		type: 'Төр',
		typeBtn: 'Төймә',
		typeSbm: 'Җибәрү',
		typeRst: 'Кире кайтару'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox Properties', // MISSING
		radioTitle: 'Радио төймə үзлекләре',
		value: 'Күләм',
		selected: 'Сайланган',
		required: 'Мәҗбүри'
	},
	form: {
		title: 'Форма үзлекләре',
		menu: 'Форма үзлекләре',
		action: 'Гамәл',
		method: 'Ысул',
		encoding: 'Кодировка'
	},
	hidden: {
		title: 'Яшерен кыр үзлекләре',
		name: 'Исем',
		value: 'Күләм'
	},
	select: {
		title: 'Selection Field Properties', // MISSING
		selectInfo: 'Информацияне сайлау',
		opAvail: 'Мөмкин булган көйләүләр',
		value: 'Күләм',
		size: 'Зурлык',
		lines: 'юллар',
		chkMulti: 'Allow multiple selections', // MISSING
		required: 'Мәҗбүри',
		opText: 'Текст',
		opValue: 'Күләм',
		btnAdd: 'Кушу',
		btnModify: 'Үзгәртү',
		btnUp: 'Өскә',
		btnDown: 'Аска',
		btnSetValue: 'Сайланган күләм булып билгеләргә',
		btnDelete: 'Бетерү'
	},
	textarea: {
		title: 'Текст мәйданы үзлекләре',
		cols: 'Баганалар',
		rows: 'Юллар'
	},
	textfield: {
		title: 'Текст кыры үзлекләре',
		name: 'Исем',
		value: 'Күләм',
		charWidth: 'Символлар киңлеге',
		maxChars: 'Maximum Characters', // MISSING
		required: 'Мәҗбүри',
		type: 'Төр',
		typeText: 'Текст',
		typePass: 'Сер сүз',
		typeEmail: 'Эл. почта',
		typeSearch: 'Эзләү',
		typeTel: 'Телефон номеры',
		typeUrl: 'Сылталама'
	}
} );
